@@ -17,6 +17,10 @@ describe 'placement::api' do
         :enabled        => true,
         :ensure_package => 'present',
       ) }
+
+      it { should contain_oslo__middleware('placement_config').with(
+        :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+      ) }
     end
 
     context 'with package_ensure parameter provided' do
@@ -46,6 +50,16 @@ describe 'placement::api' do
 
       it { should contain_class('placement::db::sync') }
     end
+
+    context 'with enable_proxy_headers_parsing set' do
+      let :params do
+        { :enable_proxy_headers_parsing => true }
+      end
+
+      it { should contain_oslo__middleware('placement_config').with(
+        :enable_proxy_headers_parsing => true,
+      ) }
+    end
   end
 
   on_supported_os({
@@ -63,7 +77,7 @@ describe 'placement::api' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
+          if facts[:operatingsystem] == 'Debian'
             { :service_name => 'placement-api',
               :package_name => 'placement-api'}
           else
